plot_fermi_isoslider — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# plot_fermi_isoslider

FermiHandler.plot_fermi_isoslider(mode, iso_range: float | None = None, iso_surfaces: int | None = None, iso_values: List[float] | None = None, bands=None, atoms=None, orbitals=None, spins=None, spin_texture=False, show=True, save_2d=None, print_plot_opts: bool = False, **kwargs)

  A method to plot the 3d fermi surface

  Parameters:

    - iso_range (float) – A range of energies the slide will go through

    - iso_surfaces (int) – Ther number of fermi sruface to calculate on the range

    - iso_range (List[int], optional) – A list of of energies the slider will go through

    - mode (str) – The mode to calculate

    - bands (List[int], optional) – A list of band indexes to plot, by default None

    - atoms (List[int], optional) – A list of atoms, by default None

    - orbitals (List[int], optional) – A list of orbitals, by default None

    - spins (List[int], optional) – A list of spins, by default None

    - spin_texture (bool, optional) – Boolean to plot spin texture, by default False

    - print_plot_opts (bool, optional) – Boolean to print the plotting options